package org.randombits.support.core.param;

import org.randombits.utils.lang.ClassUtils;

/**
 * Abstract base implementation of {@link ParameterInterpreter}. Subclasses
 * that have a concrete type can simple call the {@link #AbstractParameterInterpreter()}
 * constructor. If the subclass has a generic {@link T} type declared, it must pass
 * a Class to {@link #AbstractParameterInterpreter(Class)}.
 */
public abstract class AbstractParameterInterpreter<T> implements ParameterInterpreter<T> {

    private final Class<T> type;

    @SuppressWarnings("unchecked")
    public AbstractParameterInterpreter() {
        type = (Class<T>) ClassUtils.getTypeArguments( AbstractParameterInterpreter.class, getClass() ).get( 0 );
        assert type != null;
    }

    public AbstractParameterInterpreter( Class<T> type ) {
        this.type = type;
    }

    @Override
    public Class<T> getTargetType() {
        return type;
    }
}
