package org.randombits.support.core.param.general;

import org.randombits.support.core.param.AbstractParameterInterpreter;
import org.randombits.support.core.param.InterpretationException;
import org.randombits.support.core.param.ParameterContext;

/**
 * Converts a String into a Boolean value.
 */
public class BooleanInterpreter extends AbstractParameterInterpreter<Boolean> {

    @Override
    public Boolean interpret( String inputValue, ParameterContext context ) throws InterpretationException {
        BooleanValues values = context.get( BooleanValues.class, null );
        if ( values != null ) {
            return parseValue( inputValue, values );
        } else {
            return Boolean.parseBoolean( inputValue );
        }
    }

    private Boolean parseValue( String inputValue, BooleanValues values ) {
        for ( String trueValue : values.isTrue() ) {
            if ( trueValue.equals( inputValue ) )
                return Boolean.TRUE;
        }

        for ( String falseValue : values.isFalse() ) {
            if ( falseValue.equals( inputValue ) )
                return Boolean.FALSE;
        }
        return null;
    }
}
